@@ -314,14 +314,6 @@ PAM_EXTERN int pam_sm_authenticate(pam_handle_t *pamh, int flags, int argc, cons
         return PAM_IGNORE;
     }
 
-    //if sm_open_session has already been called (but we did not have password), call it now
-    const char *session_bit;
-    result = pam_get_data(pamh, "sm_open_session", (const void **)&session_bit);
-    if (result == PAM_SUCCESS) {
-        pam_syslog(pamh, LOG_ERR, "%s: open_session was called before us, calling it now", logPrefix);
-        return pam_sm_open_session(pamh, flags, argc, argv);
-    }
-
     //TODO unlock kwallet that is already executed
     return PAM_IGNORE;
 }
@@ -550,17 +542,9 @@ PAM_EXTERN int pam_sm_open_session(pam_handle_t *pamh, int flags, int argc, cons
         return PAM_IGNORE;
     }
 
-    int result;
-    result = pam_set_data(pamh, "sm_open_session", "1", NULL);
-    if (result != PAM_SUCCESS) {
-        pam_syslog(pamh, LOG_ERR, "%s: Impossible to store sm_open_session: %s",
-                   logPrefix, pam_strerror(pamh, result));
-        return PAM_IGNORE;
-    }
-
-     //Fetch the user, needed to get user information
+    //Fetch the user, needed to get user information
     const char *username;
-    result = pam_get_user(pamh, &username, NULL);
+    int result = pam_get_user(pamh, &username, NULL);
     if (result != PAM_SUCCESS) {
         pam_syslog(pamh, LOG_ERR, "%s: Couldn't get username %s",
                    logPrefix, pam_strerror(pamh, result));
@@ -584,7 +568,7 @@ PAM_EXTERN int pam_sm_open_session(pam_handle_t *pamh, int flags, int argc, cons
 
     if (result != PAM_SUCCESS) {
         pam_syslog(pamh, LOG_INFO, "%s: open_session called without %s", logPrefix, kwalletPamDataKey);
-        return PAM_SUCCESS;//We will wait for pam_sm_authenticate
+        return PAM_IGNORE;
     }
 
     char *key = malloc(KWALLET_PAM_KEYSIZE);
